<?php

namespace App\Http\Controllers\Admin;

use App\Models\Post;
use Auth;
use DB;
use Toastr;
use Session;

use App\Models\Formation;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\File;
use Intervention\Image\Facades\Image;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use App\Models\Image as ImageModel;


class FormationController extends Controller
{

    // private $dir_images     ;

    // public function __construct() {
    //     $this->dir_images     = '/app/public/images/';

    //     // check if directory exixt or make it
    //     if( !is_dir( storage_path().$this->dir_images ) ){
    //         @mkdir( storage_path().$this->dir_images , 0777 );
    //     }
    // }


    public function index()
    {
        $formations = Formation::latest()->get(); 
        // $postsTrending = Post::where('type_post', 'TRENDING')->get(); 

        return view('admin.pages.formations.index', compact('formations'));
    }



    public function create()
    {
        return view('admin.pages.formations.create');
    }




    public function store(Request $request)
    {

        $this->validate($request,[
            'title'       => 'required',
            'image'       => 'required',
        ]);

        $image = $request->file('image');
        $slug  = Str::slug($request->title);
        
        if(isset($image)){
            $currentDate = Carbon::now()->toDateString();
            $imageName= $slug.'-'.$currentDate.'-'.uniqid().'.'.$image->getClientOriginalExtension();
           
            if(!Storage::disk('public')->exists('formations')){
                Storage::disk('public')->makeDirectory('formations');}

            $img = Image::make($image->getRealPath());
            $img->stream(); // <-- Key point
            Storage::disk('local')->put('public/formations/'.$imageName, $img);   

        } else {
            $imageName = "default.png";
        }

        $formation= new Formation();
        $formation->title        = $request->title;
        $formation->slug         = $slug;
        $formation->image        = $imageName;
        $formation->body  = $request->body;


        $formation->meta_title        = $request->meta_title;
        $formation->meta_keywords     = $request->meta_keywords;
        $formation->meta_description  = $request->meta_description;

        $formation->status       = $request->has('status')? true:false;
        $formation->save();

        if( $request->has('gallery') ){
            $listIds = json_decode( $request->gallery , true );
            foreach ($listIds as $imageId ){
                $images[] = ImageModel::find($imageId);
            }
            if( @$images ){
                $formation->images()->saveMany($images);
            }
        }
        
        return redirect()->route('admin.formations.index')->with( ['message' => __('The action ran successfully!') ] );



    }


    public function enable($id) {
        $formation = Formation::findOrFail($id);
            if ($formation->status == 1)          
            { Formation::where('id', $id)->update(['status' => 0]);
            Toastr::success('message', 'élement invisible.'); }
            else
            { Formation::where('id', $id)->update(['status' => 1]);
            Toastr::success('message', 'élement visible.'); }
          
          return redirect('/panel/formations');
    }







    public function edit(formation $formation)
    {

        return view('admin.pages.formations.edit', compact('formation'));
}





    public function update(Request $request,$id)
    { 
          
        $this->validate($request,[
            // 'title'       => 'required',
            // 'image'       => 'required',
        ]);

        $formation = Formation::find($id);

        $image = $request->file('image');
        $slug  = Str::slug($request->title);
        
        if(isset($image)){
            $currentDate = Carbon::now()->toDateString();
            $imageName= $slug.'-'.$currentDate.'-'.uniqid().'.'.$image->getClientOriginalExtension();


            if(!Storage::disk('public')->exists('formations')){

                Storage::disk('public')->makeDirectory('formations');
            }

            // Delete old image
            if(Storage::disk('public')->exists('formations/'.$formation->image)){
                Storage::disk('public')->delete('formations/'.$formation->image);
            }

            // resizeimage
            $formationImage = Image::make($image)->resize(1600,1066)->save($imageName, 90);
            Storage::disk('public')->put('formations/'.$imageName, $formationImage);

        } else {
            $imageName = $formation->image;
        }

        // $formation->admin_id     = Auth::id();
        $formation->title        = $request->title;
        $formation->slug         = $slug;
        $formation->image        = $imageName;
        $formation->body  = $request->body;

        $formation->meta_title        = $request->meta_title;
        $formation->meta_keywords     = $request->meta_keywords;
        $formation->meta_description  = $request->meta_description;

        $formation->status       = $request->has('status')?true:false;

        if( $imageList = $request->has('gallery') ){
            $listIds = json_decode( $request->gallery , true );
            foreach ($listIds as $imageId ){
                $images[] = ImageModel::find($imageId);
            }
            if( @$images ){
                $formation->images()->saveMany($images);
            }
        }


        $formation->save();

        return redirect('/panel/formations');
    }





    public function destroy( $formation)
    {  
        
        $formation = Formation::where([ "id" => $formation  ])->firstOrFail();
        
        // $formation = formation::find($id);
        if(Storage::disk('public')->exists('formations/'.$formation->image)){
            Storage::disk('public')->delete('formations/'.$formation->image);
        }

        if( $formation->gallery ){
            foreach( $formation->gallery as $image ){
                @File::delete( storage_path( "/app/public/images/".$image->name ) );
                $image->delete();
            }
        }
        $formation->delete();
        return redirect('/panel/formations');
    }




}
