<?php

namespace App\Http\Controllers\Admin;

use App\Models\Post;
use Auth;
use DB;
use Toastr;
use Session;

use App\Models\Service;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\File;
use Intervention\Image\Facades\Image;
use Illuminate\Validation\Rule;
use Carbon\Carbon;
use App\Models\Image as ImageModel;


class ServiceController extends Controller
{

    // private $dir_images     ;

    // public function __construct() {
    //     $this->dir_images     = '/app/public/images/';

    //     // check if directory exixt or make it
    //     if( !is_dir( storage_path().$this->dir_images ) ){
    //         @mkdir( storage_path().$this->dir_images , 0777 );
    //     }
    // }


    public function index()
    {
        $services = Service::latest()->get(); 
        return view('admin.pages.services.index', compact('services'));
    }


    public function create()
    {
        return view('admin.pages.services.create');
    }


    public function store(Request $request)
    {

        $this->validate($request,[
            'title'       => 'required',
            'image'       => 'required',
        ]);

        $image = $request->file('image');
        $slug  = Str::slug($request->title);
        
        if(isset($image)){
            $currentDate = Carbon::now()->toDateString();
            $imageName= $slug.'-'.$currentDate.'-'.uniqid().'.'.$image->getClientOriginalExtension();
           
            if(!Storage::disk('public')->exists('services')){
                Storage::disk('public')->makeDirectory('services');}

            $img = Image::make($image->getRealPath());
            $img->stream(); // <-- Key point
            Storage::disk('local')->put('public/services/'.$imageName, $img);   

        } else {
            $imageName = "default.png";
        }

        $service= new Service();
        $service->title        = $request->title;
        $service->slug         = $slug;
        $service->image        = $imageName;
        $service->body         = $request->body;

        $service->meta_title        = $request->meta_title;
        $service->meta_keywords     = $request->meta_keywords;
        $service->meta_description  = $request->meta_description;

        $service->status       = $request->has('status')? true:false;
        $service->save();

        if( $request->has('gallery') ){
            $listIds = json_decode( $request->gallery , true );
            foreach ($listIds as $imageId ){
                $images[] = ImageModel::find($imageId);
            }
            if( @$images ){
                $service->images()->saveMany($images);
            }
        }
        
        return redirect()->route('admin.services.index')->with( ['message' => __('The action ran successfully!') ] );
    }


    public function enable($id) {
        $services = Service::findOrFail($id);
            if ($services->status == 1)          
            { Service::where('id', $id)->update(['status' => 0]);
            Toastr::success('message', 'élement invisible.'); }
            else
            { Service::where('id', $id)->update(['status' => 1]);
            Toastr::success('message', 'élement visible.'); }
          
          return redirect('/panel/services');
    }



    public function edit(Service $service)
    {

        return view('admin.pages.services.edit', compact('service'));
    }


    public function update(Request $request,$id)
    { 
          
        $this->validate($request,[
            // 'title'       => 'required',
            // 'image'       => 'required',
        ]);

        $service = Service::find($id);

        $image = $request->file('image');
        $slug  = Str::slug($request->title);
        
        if(isset($image)){
            $currentDate = Carbon::now()->toDateString();
            $imageName= $slug.'-'.$currentDate.'-'.uniqid().'.'.$image->getClientOriginalExtension();


            if(!Storage::disk('public')->exists('services')){

                Storage::disk('public')->makeDirectory('services');
            }

            // Delete old image
            if(Storage::disk('public')->exists('services/'.$service->image)){
                Storage::disk('public')->delete('services/'.$service->image);
            }

            // resizeimage
            $serviceImage = Image::make($image)->resize(1600,1066)->save($imageName, 90);
            Storage::disk('public')->put('services/'.$imageName, $serviceImage);

        } else {
            $imageName = $service->image;
        }

        // $formationContinue->admin_id     = Auth::id();
        $service->title        = $request->title;
        $service->slug         = $slug;
        $service->image        = $imageName;
        $service->body  = $request->body;

        $service->meta_title        = $request->meta_title;
        $service->meta_keywords     = $request->meta_keywords;
        $service->meta_description  = $request->meta_description;

        $service->status       = $request->has('status')?true:false;

        if( $imageList = $request->has('gallery') ){
            $listIds = json_decode( $request->gallery , true );
            foreach ($listIds as $imageId ){
                $images[] = ImageModel::find($imageId);
            }
            if( @$images ){
                $service->images()->saveMany($images);
            }
        }

        $service->save();

        return redirect('/panel/services');
    }





    public function destroy( $service)
    {  
        $service = Service::where([ "id" => $service  ])->firstOrFail();
        
        // $service = service::find($id);
        if(Storage::disk('public')->exists('services/'.$service->image)){
            Storage::disk('public')->delete('services/'.$service->image);
        }

        if( $service->gallery ){
            foreach( $service->gallery as $image ){
                @File::delete( storage_path( "/app/public/images/".$image->name ) );
                $image->delete();
            }
        }
        $service->delete();
        return redirect('/panel/services');
    }




}
