@extends('admin.layouts.app')
@section('title', __('admins') )

@section('content')

@if ($errors->any())
    <div class="rounded-md flex items-center px-5 py-4 mb-2 bg-theme-31 text-theme-6"> <i data-feather="alert-octagon" class="w-6 h-6 mr-2"></i>
        <ul>
            @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
            @endforeach
        </ul>
    </div>
@endif

@if(session()->has('message'))
    <div class="rounded-md flex items-center px-5 py-4 mb-2 bg-theme-18 text-theme-9"> <i data-feather="alert-triangle" class="w-6 h-6 mr-2"></i> {{ session()->get('message') }} </div>
@endif

<div class="grid grid-cols-12 gap-6 mt-5">
    <div class="intro-y col-span-12 box p-5">
        <a href="{{ route('admin.admin.create') }}" class="button w-32 mr-2 mb-2 flex items-center justify-center bg-theme-1 text-white"> <i data-feather="plus" class="w-4 h-4 mr-2"></i> {{ __("Add") }} </a>
        <div class="overflow-x-auto">
            <table class="table mb-2 mt-4 ">
                <thead>
                    <tr class="bg-gray-100 rounded">
                        <th class="border-b-2 whitespace-no-wrap" width="5%"> Image </th>
                        <th class="border-b-2 whitespace-no-wrap" width="5%"> </th>
                        <th class="border-b-2 whitespace-no-wrap"> Name </th>
                        <th class="border-b-2 whitespace-no-wrap"> Email  </th>
                        <th class="border-b-2 whitespace-no-wrap"> Phone  </th>
                        <th class="border-b-2 whitespace-no-wrap"> Status  </th>
                        <th class="border-b-2 whitespace-no-wrap text-center" width="10%"> {{ __('Action') }} </th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($admins as $admin)
                        <tr class="hover:bg-gray-200">
                            <td class="border-b">
                                @if( $admin->image )
                                    <img src="{{ $admin->image->pathThumbnail }}" height="50" />
                                @endif
                            </td>
                            <td class="border-b">
                                @if( $admin->is_super )
                                    <div class="font-medium whitespace-no-wrap"> <i data-feather="gitlab"></i> </div>
                                @endif
                            </td>
                            <td class="border-b">
                                <div class="font-medium whitespace-no-wrap"> {{ $admin->name }} </div>
                            </td>
                            <td class="border-b">
                                <div class="font-medium whitespace-no-wrap"> {{ $admin->email }} </div>
                            </td>
                            <td class="border-b">
                                <div class="font-medium whitespace-no-wrap"> {{ $admin->phone }} </div>
                            </td>
                            <td class="border-b">
                                <div class="font-medium whitespace-no-wrap">
                                    <span class="py-1 px-2 rounded-full text-xs text-white cursor-pointer {{ $admin->is_active == true ? 'bg-green-400' : 'bg-red-500' }}" > {{ $admin->is_active ? 'Active' : 'Non active'  }} </span>
                                </div>
                            </td>
                            <td class="border-b">
                                <div class="flex sm:justify-center items-center">
                                    <a class="flex items-center mr-3" href="{{ route('admin.admin.edit',$admin) }}"> <i data-feather="check-square" class="w-4 h-4 mr-1"></i> {{__('Edit')}} </a>
                                    @if( Auth::user()->id !== $admin->id )
                                    <a class="flex items-center text-theme-6" href="#" onclick="event.preventDefault();document.getElementById('delete-form-{{$admin->id}}').submit();" > <i data-feather="trash-2" class="w-4 h-4 mr-1"></i> {{__('Delete')}} </a>
                                    <form id="delete-form-{{$admin->id}}" action="{{ route('admin.admin.destroy', $admin) }}" method="POST" class="d-none"> @csrf @method('DELETE') </form>
                                    @endif
                                </div>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>

            {{ $admins->links() }}
        </div>
    </div>
</div>
@endsection

@section('javascript')
    <script>

    </script>
@endsection
